@@ -1,7 +1,8 @@
 from .decorator import load_config
-from .module_loader import ModuleLoader
+from .module_loader import ModuleLoader, ModuleLoaderSetting
 
 __all__ = (
     "load_config",
     "ModuleLoader",
+    "ModuleLoaderSetting",
 )
